from django.apps import AppConfig
from django.utils.translation import gettext_lazy as _


class FormDesignerConfig(AppConfig):
    name = "form_designer"
    verbose_name = _("Form Designer")
